#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sites_site_id_wireless_settings_flex_connect_aaa_override
short_description: Resource module for Sites Site Id Wireless Settings Flex Connect Aaa Override
description:
  - Manage operations update and delete of the resource Sites Site Id Wireless Settings Flex Connect Aaa Override.
  - This API allows the user to delete AAA Override VLAN settings at the given site level.
  - This API allows the user to update an existing AAA Override VLAN setting at the given site level.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  payload:
    description: Sites Site Id Wireless Settings Flex Connect Aaa Override's payload.
    elements: dict
    suboptions:
      vlanId:
        description: The VLAN ID is a identifier used to uniquely distinguish a Virtual Local Area Network (VLAN) within a
          network.Range is 1 to 4094.
        type: int
      vlanName:
        description: The VLAN NAME is a label assigned to a Virtual Local Area Network (VLAN) to identify and differentiate
          it within a network.Max allowed characters is 32.
        type: str
    type: list
  removeOverrideInHierarchy:
    description: RemoveOverrideInHierarchy query parameter. If the siteId pertains to a Global or non-Global site (e.g., Global,
      Area, Building, or Floor) and removeOverrideInHierarchy is set to true, this API will remove the override from the specified
      siteId and any child sites for the same AAA Override VLAN. If removeOverrideInHierarchy is set to false, the API will
      only remove the override from the specified siteId only, leaving any overrides for the AAA Override VLAN at child sites
      unaffected.
    type: bool
  siteId:
    description: SiteId path parameter. Site Id.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless DeleteAAAOverrideVlanSettingsBySite
    description: Complete reference of the DeleteAAAOverrideVlanSettingsBySite API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-aaa-override-vlan-settings-by-site
  - name: Cisco DNA Center documentation for Wireless UpdateAAAOverrideVlanSettingsBySite
    description: Complete reference of the UpdateAAAOverrideVlanSettingsBySite API.
    link: https://developer.cisco.com/docs/dna-center/#!update-aaa-override-vlan-settings-by-site
notes:
  - SDK Method used are
    wireless.Wireless.delete_aaa_override_vlan_settings_by_site,
    wireless.Wireless.update_aaa_override_vlan_settings_by_site,
  - Paths used are
    delete /dna/intent/api/v1/sites/{siteId}/wirelessSettings/flexConnectAaaOverride,
    put /dna/intent/api/v1/sites/{siteId}/wirelessSettings/flexConnectAaaOverride,
"""

EXAMPLES = r"""
---
- name: Delete all
  cisco.dnac.sites_site_id_wireless_settings_flex_connect_aaa_override:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    removeOverrideInHierarchy: true
    siteId: string
- name: Update all
  cisco.dnac.sites_site_id_wireless_settings_flex_connect_aaa_override:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - vlanId: 0
        vlanName: string
    siteId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: compliance_device_by_id_info
short_description: Information module for Compliance Device By Id
description:
  - Get all Compliance Device By Id.
  - Return compliance detailed report for a device.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  deviceUuid:
    description:
      - DeviceUuid path parameter. Device Id.
    type: str
  category:
    description:
      - >
        Category query parameter. Category can have any value among 'INTENT', 'RUNNING_CONFIG' , 'IMAGE' ,
        'PSIRT' , 'DESIGN_OOD' , 'EOX' , 'NETWORK_SETTINGS'.
    type: str
  complianceType:
    description:
      - >
        ComplianceType query parameter. Specify "Compliance type(s)" separated by commas. The Compliance type
        can be 'APPLICATION_VISIBILITY', 'EOX', 'FABRIC', 'IMAGE', 'NETWORK_PROFILE', 'NETWORK_SETTINGS',
        'PSIRT', 'RUNNING_CONFIG', 'WORKFLOW'.
    type: str
  diffList:
    description:
      - DiffList query parameter. Diff list pass true to fetch the diff list.
    type: bool
  status:
    description:
      - >
        Status query parameter. 'COMPLIANT', 'NON_COMPLIANT', 'ERROR', 'IN_PROGRESS', 'NOT_APPLICABLE',
        'NOT_AVAILABLE', 'WARNING', 'REMEDIATION_IN_PROGRESS' can be the value of the compliance 'status'
        parameter. COMPLIANT Device currently meets the compliance requirements. NON_COMPLIANT One of the
        compliance requirements like Software Image, PSIRT, Network Profile, Startup vs Running, etc. Are not
        met. ERROR Compliance is unable to compute status due to underlying errors. IN_PROGRESS Compliance check
        is in progress for the device. NOT_APPLICABLE Device is not supported for compliance, or minimum license
        requirement is not met. NOT_AVAILABLE Compliance is not available for the device. COMPLIANT_WARNING The
        device is compliant with warning if the last date of support is nearing. REMEDIATION_IN_PROGRESS
        Compliance remediation is in progress for the device.
    type: str
  remediationSupported:
    description:
      - >
        RemediationSupported query parameter. The 'remediationSupported' parameter can be set to 'true' or
        'false'. The result will be a combination of both values if it is not provided.
    type: bool
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Compliance ComplianceDetailsOfDevice
    description: Complete reference of the ComplianceDetailsOfDevice API.
    link: https://developer.cisco.com/docs/dna-center/#!compliance-details-of-device
notes:
  - SDK Method used are
    compliance.Compliance.compliance_details_of_device,
  - Paths used are
    get /dna/intent/api/v1/compliance/{deviceUuid}/detail,
"""

EXAMPLES = r"""
---
- name: Get all Compliance Device By Id
  cisco.dnac.compliance_device_by_id_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    category: string
    complianceType: string
    diffList: true
    status: string
    remediationSupported: true
    deviceUuid: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "deviceUuid": "string",
          "complianceType": "string",
          "status": "string",
          "state": "string",
          "lastSyncTime": 0,
          "lastUpdateTime": 0,
          "sourceInfoList": [
            {
              "name": "string",
              "nameWithBusinessKey": "string",
              "sourceEnum": "string",
              "type": "string",
              "appName": "string",
              "count": 0,
              "ackStatus": "string",
              "businessKey": {
                "resourceName": "string",
                "businessKeyAttributes": {},
                "otherAttributes": {
                  "name": "string",
                  "cfsAttributes": {
                    "displayName": "string",
                    "appName": "string",
                    "description": "string",
                    "source": "string",
                    "type": "string"
                  }
                }
              },
              "diffList": [
                {
                  "op": "string",
                  "configuredValue": "string",
                  "intendedValue": "string",
                  "moveFromPath": "string",
                  "businessKey": "string",
                  "path": "string",
                  "extendedAttributes": {
                    "attributeDisplayName": "string",
                    "path": "string",
                    "dataConverter": "string",
                    "type": "string"
                  },
                  "ackStatus": "string",
                  "instanceUUID": "string",
                  "displayName": "string"
                }
              ],
              "displayName": "string"
            }
          ],
          "ackStatus": "string",
          "version": "string",
          "remediationSupported": true
        }
      ],
      "deviceUuid": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: fabric_site_health_summaries_info
short_description: Information module for Fabric Site Health Summaries
description:
  - Get all Fabric Site Health Summaries.
  - Get Fabric Site Health Summaries by id.
  - Get Fabric site health summary for a specific fabric site by providing the unique fabric site id in the url path.
  - Get a paginated list of Fabric sites Networks with health summary.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which API queries the data set related to the resource. It
        must be specified in UNIX epochtime in milliseconds. Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API queries the data set related to the resource. It must be
        specified in UNIX epochtime in milliseconds. Value is inclusive.
    type: float
  limit:
    description:
      - Limit query parameter. Maximum number of records to return.
    type: int
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting point within all records returned by the API. It's one
        based offset. The starting value is 1.
    type: int
  sortBy:
    description:
      - SortBy query parameter. A field within the response to sort by.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the field ascending or descending.
    type: str
  id:
    description:
      - >
        Id query parameter. The list of entity Uuids. (Ex."6bef213c-19ca-4170-8375-b694e251101c") Examples
        id=6bef213c-19ca-4170-8375-b694e251101c (single entity uuid requested) id=6bef213c-19ca-4170-8375-
        b694e251101c&id=32219612-819e-4b5e-a96b-cf22aca13dd9&id=2541e9a7-b80d-4955-8aa2-79b233318ba0 (multiple
        entity uuid with '&' separator).
    type: str
  attribute:
    description:
      - >
        Attribute query parameter. The list of FabricSite health attributes. Please refer to
        ```fabricSiteAttributes``` section in the Open API specification document mentioned in the description.
    type: str
  view:
    description:
      - >
        View query parameter. The specific summary view being requested. A maximum of 3 views can be queried at
        a time per request. Please refer to ```fabricSiteViews``` section in the Open API specification document
        mentioned in the description.
    type: str
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical breakdown of the site tree starting from Global
        site name and ending with the specific site name. The Root site is named "Global" (Ex.
        `Global/AreaName/BuildingName/FloorName`) This field supports wildcard asterisk (`*`) character search
        support. E.g. `*/San*, */San, /San*` Examples `?siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `?siteHierarchy=Global/AreaName/BuildingName/FloorName&siteHierarchy=Gl
        obal/AreaName2/BuildingName2/FloorName2` (multiple siteHierarchies requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy breakdown of the site tree in id form starting from
        Global site UUID and ending with the specific site UUID. (Ex.
        `globalUuid/areaUuid/buildingUuid/floorUuid`) This field supports wildcard asterisk (`*`) character
        search support. E.g. `*uuid*, *uuid, uuid*` Examples
        `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid `(single siteHierarchyId requested) `?siteH
        ierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globalUuid/areaUuid2/buildingUuid2
        /floorUuid2` (multiple siteHierarchyIds requested).
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for SDA ReadFabricSitesWithHealthSummaryFromId
    description: Complete reference of the ReadFabricSitesWithHealthSummaryFromId API.
    link: https://developer.cisco.com/docs/dna-center/#!read-fabric-sites-with-health-summary-from-id
  - name: Cisco DNA Center documentation for SDA ReadListOfFabricSitesWithTheirHealthSummary
    description: Complete reference of the ReadListOfFabricSitesWithTheirHealthSummary API.
    link: https://developer.cisco.com/docs/dna-center/#!read-list-of-fabric-sites-with-their-health-summary
notes:
  - SDK Method used are
    sda.Sda.read_fabric_sites_with_health_summary_from_id,
    sda.Sda.read_list_of_fabric_sites_with_their_health_summary,
  - Paths used are
    get /dna/data/api/v1/fabricSiteHealthSummaries,
    get /dna/data/api/v1/fabricSiteHealthSummaries/{id},
"""

EXAMPLES = r"""
---
- name: Get all Fabric Site Health Summaries
  cisco.dnac.fabric_site_health_summaries_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    limit: 0
    offset: 0
    sortBy: string
    order: string
    id: string
    attribute: string
    view: string
    siteHierarchy: string
    siteHierarchyId: string
  register: result
- name: Get Fabric Site Health Summaries by id
  cisco.dnac.fabric_site_health_summaries_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    attribute: string
    view: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "name": "string",
        "totalDeviceCount": 0,
        "goodHealthPercentage": 0,
        "totalHealthDeviceCount": 0,
        "goodHealthDeviceCount": 0,
        "poorHealthDeviceCount": 0,
        "fairHealthDeviceCount": 0,
        "connectivityGoodHealthPercentage": 0,
        "connectivityTotalHealthDeviceCount": 0,
        "connectivityGoodHealthDeviceCount": 0,
        "connectivityPoorHealthDeviceCount": 0,
        "connectivityFairHealthDeviceCount": 0,
        "infraGoodHealthPercentage": 0,
        "infraTotalHealthDeviceCount": 0,
        "infraGoodHealthDeviceCount": 0,
        "infraFairHealthDeviceCount": 0,
        "infraPoorHealthDeviceCount": 0,
        "controlPlaneGoodHealthPercentage": 0,
        "controlPlaneTotalHealthDeviceCount": 0,
        "controlPlaneGoodHealthDeviceCount": 0,
        "controlPlanePoorHealthDeviceCount": 0,
        "controlPlaneFairHealthDeviceCount": 0,
        "pubsubInfraVnGoodHealthPercentage": 0,
        "pubsubInfraVnTotalHealthDeviceCount": 0,
        "pubsubInfraVnGoodHealthDeviceCount": 0,
        "pubsubInfraVnPoorHealthDeviceCount": 0,
        "pubsubInfraVnFairHealthDeviceCount": 0,
        "bgpEvpnGoodHealthPercentage": 0,
        "bgpEvpnTotalHealthDeviceCount": 0,
        "bgpEvpnGoodHealthDeviceCount": 0,
        "bgpEvpnPoorHealthDeviceCount": 0,
        "bgpEvpnFairHealthDeviceCount": 0,
        "ctsEnvDataDownloadGoodHealthPercentage": 0,
        "ctsEnvDataDownloadTotalHealthDeviceCount": 0,
        "ctsEnvDataDownloadGoodHealthDeviceCount": 0,
        "ctsEnvDataDownloadPoorHealthDeviceCount": 0,
        "ctsEnvDataDownloadFairHealthDeviceCount": 0,
        "aaaStatusGoodHealthPercentage": 0,
        "aaaStatusTotalHealthDeviceCount": 0,
        "aaaStatusGoodHealthDeviceCount": 0,
        "aaaStatusPoorHealthDeviceCount": 0,
        "aaaStatusFairHealthDeviceCount": 0,
        "portChannelGoodHealthPercentage": 0,
        "portChannelTotalHealthDeviceCount": 0,
        "portChannelGoodHealthDeviceCount": 0,
        "portChannelPoorHealthDeviceCount": 0,
        "portChannelFairHealthDeviceCount": 0,
        "peerScoreGoodHealthPercentage": 0,
        "peerScoreTotalHealthDeviceCount": 0,
        "peerScoreGoodHealthDeviceCount": 0,
        "peerScorePoorHealthDeviceCount": 0,
        "peerScoreFairHealthDeviceCount": 0,
        "lispSessionGoodHealthPercentage": 0,
        "lispSessionTotalHealthDeviceCount": 0,
        "lispSessionGoodHealthDeviceCount": 0,
        "lispSessionPoorHealthDeviceCount": 0,
        "lispSessionFairHealthDeviceCount": 0,
        "borderToControlPlaneGoodHealthPercentage": 0,
        "borderToControlPlaneTotalHealthDeviceCount": 0,
        "borderToControlPlaneGoodHealthDeviceCount": 0,
        "borderToControlPlanePoorHealthDeviceCount": 0,
        "borderToControlPlaneFairHealthDeviceCount": 0,
        "bgpBgpSiteGoodHealthPercentage": 0,
        "bgpBgpSiteTotalHealthDeviceCount": 0,
        "bgpBgpSiteGoodHealthDeviceCount": 0,
        "bgpBgpSitePoorHealthDeviceCount": 0,
        "bgpBgpSiteFairHealthDeviceCount": 0,
        "bgpPubsubSiteGoodHealthPercentage": 0,
        "bgpPubsubSiteTotalHealthDeviceCount": 0,
        "bgpPubsubSiteGoodHealthDeviceCount": 0,
        "bgpPubsubSitePoorHealthDeviceCount": 0,
        "bgpPubsubSiteFairHealthDeviceCount": 0,
        "bgpPeerInfraVnScoreGoodHealthPercentage": 0,
        "bgpPeerInfraVnTotalHealthDeviceCount": 0,
        "bgpPeerInfraVnGoodHealthDeviceCount": 0,
        "bgpPeerInfraVnPoorHealthDeviceCount": 0,
        "bgpPeerInfraVnFairHealthDeviceCount": 0,
        "associatedL2VnCount": 0,
        "associatedL3VnCount": 0,
        "networkProtocol": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_accesspoint_configuration_summary_info
short_description: Information module for Wireless Accesspoint Configuration Summary
description:
  - Get all Wireless Accesspoint Configuration Summary. - > Users can query access point configuration information for a specific
    device by using the Ethernet MAC address as a 'key' filter. If no key is specified, all access point details will be retrieved
    based on the combination of filters provided.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  key:
    description:
      - Key query parameter. The ethernet MAC address of Access point.
    type: str
  wlcIpAddress:
    description:
      - WlcIpAddress query parameter. WLC IP Address.
    type: str
  apMode:
    description:
      - >
        ApMode query parameter. AP Mode. Allowed values are Local, Bridge, Monitor, FlexConnect, Sniffer, Rogue
        Detector, SE-Connect, Flex+Bridge, Sensor.
    type: str
  apModel:
    description:
      - ApModel query parameter. AP Model.
    type: str
  meshRole:
    description:
      - MeshRole query parameter. Mesh Role. Allowed values are RAP or MAP.
    type: str
  provisioned:
    description:
      - Provisioned query parameter. Indicate whether AP provisioned or not. Allowed values are True or False.
    type: str
  limit:
    description:
      - >
        Limit query parameter. The number of records to show for this page. The default is 500 if not specified.
        The maximum allowed limit is 500.
    type: int
  offset:
    description:
      - Offset query parameter. The first record to show for this page; the first record is numbered 1.
    type: int
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless GetAccessPointConfiguration
    description: Complete reference of the GetAccessPointConfiguration API.
    link: https://developer.cisco.com/docs/dna-center/#!get-access-point-configuration
notes:
  - SDK Method used are
    wireless.Wireless.get_access_point_configuration,
  - Paths used are
    get /dna/intent/api/v1/wireless/accesspoint-configuration/summary,
"""

EXAMPLES = r"""
---
- name: Get all Wireless Accesspoint Configuration Summary
  cisco.dnac.wireless_accesspoint_configuration_summary_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    key: string
    wlcIpAddress: string
    apMode: string
    apModel: string
    meshRole: string
    provisioned: string
    limit: 0
    offset: 0
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "adminStatus": "string",
      "apHeight": 0,
      "apMode": "string",
      "apName": "string",
      "ethMac": "string",
      "failoverPriority": "string",
      "ledBrightnessLevel": 0,
      "ledStatus": "string",
      "location": "string",
      "macAddress": "string",
      "primaryControllerName": "string",
      "primaryIpAddress": "string",
      "secondaryControllerName": "string",
      "secondaryIpAddress": "string",
      "tertiaryControllerName": "string",
      "tertiaryIpAddress": "string",
      "meshDTOs": [
        "string"
      ],
      "model": "string",
      "wlcIpAddress": "string",
      "reachabilityStatus": "string",
      "managementIpAddress": "string",
      "provisioningStatus": "string",
      "radioDTOs": [
        {
          "ifType": 0,
          "ifTypeValue": "string",
          "slotId": 0,
          "macAddress": "string",
          "adminStatus": "string",
          "powerAssignmentMode": "string",
          "powerlevel": 0,
          "channelAssignmentMode": "string",
          "channelNumber": 0,
          "channelWidth": "string",
          "antennaPatternName": "string",
          "antennaAngle": 0,
          "antennaElevAngle": 0,
          "antennaGain": 0,
          "radioRoleAssignment": {},
          "radioBand": {},
          "cleanAirSI": "string",
          "dualRadioMode": "string"
        }
      ]
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_devices_query_count
short_description: Resource module for Network Devices Query Count
description:
  - Manage operation create of the resource Network Devices Query Count.
  - Gets the total number Network Devices based on the provided complex filters and aggregation functions.
  - For detailed information about the usage of the API, please refer to the Open API specification document
    https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-AssuranceNetworkDevices-2.0.1-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  endTime:
    description: End Time.
    type: int
  filters:
    description: Network Devices Query Count's filters.
    elements: dict
    suboptions:
      key:
        description: Key.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: str
    type: list
  startTime:
    description: Start Time.
    type: int
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices GetsTheTotalNumberNetworkDevicesBasedOnTheProvidedComplexFiltersAndAggregationFunctions
    description: Complete reference of the GetsTheTotalNumberNetworkDevicesBasedOnTheProvidedComplexFiltersAndAggregationFunctions
      API.
    link: https://developer.cisco.com/docs/dna-center/#!gets-the-total-number-network-devices-based-on-the-provided-complex-filters-and-aggregation-functions
notes:
  - SDK Method used are
    devices.Devices.gets_the_total_number_network_devices_based_on_the_provided_complex_filters_and_aggregation_functions,
  - Paths used are
    post /dna/data/api/v1/networkDevices/query/count,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.network_devices_query_count:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    endTime: 0
    filters:
      - key: string
        operator: string
        value: string
    startTime: 0
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: discoverys_jobs_discovered_network_devices_count_info
short_description: Information module for Discoverys Jobs Discovered Network Devices Count
description:
  - Get all Discoverys Jobs Discovered Network Devices Count.
  - API to get the details of all the devices discovered by the given jobId and discoveryId.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  discoveryId:
    description:
      - DiscoveryId path parameter. The id of the discovery.
    type: str
  jobId:
    description:
      - JobId path parameter. The id of the discovery job.
    type: str
  managementIpAddress:
    description:
      - ManagementIpAddress query parameter. Management IP address of the network device.
    type: str
  reachabilityStatus:
    description:
      - ReachabilityStatus query parameter. Reachability status of the network device.
    type: str
  ping:
    description:
      - Ping query parameter. Ping status for the IP during the job run.
    type: str
  cli:
    description:
      - Cli query parameter. CLI status for the IP during the job run.
    type: str
  snmp:
    description:
      - Snmp query parameter. SNMP status for the IP during the job run.
    type: str
  http:
    description:
      - Http query parameter. HTTP status for the IP during the job run.
    type: str
  netconf:
    description:
      - Netconf query parameter. Netconf status for the IP during the job run.
    type: str
  limit:
    description:
      - Limit query parameter. The number of records to show for this page.
    type: int
  offset:
    description:
      - Offset query parameter. The first record to show for this page; the first record is numbered 1.
    type: int
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices CountTheNumberOfDiscoveredNetworkDevicesByDiscoveryId
    description: Complete reference of the CountTheNumberOfDiscoveredNetworkDevicesByDiscoveryId API.
    link: https://developer.cisco.com/docs/dna-center/#!count-the-number-of-discovered-network-devices-by-discovery-id
notes:
  - SDK Method used are
    devices.Devices.count_the_number_of_discovered_network_devices_by_discovery_id,
  - Paths used are
    get /dna/intent/api/v1/discoverys/{discoveryId}/jobs/{jobId}/discoveredNetworkDevices/count,
"""

EXAMPLES = r"""
---
- name: Get all Discoverys Jobs Discovered Network Devices Count
  cisco.dnac.discoverys_jobs_discovered_network_devices_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    managementIpAddress: string
    reachabilityStatus: string
    ping: string
    cli: string
    snmp: string
    http: string
    netconf: string
    limit: 0
    offset: 0
    discoveryId: string
    jobId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: application_visibility_network_devices_info
short_description: Information module for Application Visibility Network Devices
description:
  - Get all Application Visibility Network Devices. - > This API retrieves the list of network devices with their application
    visibility status. The list can be filtered using the query parameters. Multiple filters can be applied.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  ids:
    description:
      - >
        Ids query parameter. List of network devices ids. If this parameter is not provided, all network devices
        will be included in the response. Multiple network device IDs can be provided.
    type: str
  managementAddress:
    description:
      - >
        ManagementAddress query parameter. The management address for the network device. This is normally IP
        address of the device. But it could be hostname in some cases like Meraki devices. Partial search is
        supported. For example, searching for `25.` would include `10.25.1.1`, `25.5.10.1`, `225.225.1.0`,
        `10.10.10.125`, etc.
    type: str
  hostname:
    description:
      - >
        Hostname query parameter. The host name of the network device. Partial search is supported. For example,
        searching for `switch` will include `edge-switch1.domain.com`, `switch25`, etc.
    type: str
  siteId:
    description:
      - SiteId query parameter. The site ID where the network device is assigned.
    type: str
  appTelemetryDeploymentStatus:
    description:
      - >
        AppTelemetryDeploymentStatus query parameter. Status of the application telemetry deployment on the
        network device. Available values SCHEDULED, IN_PROGRESS, COMPLETED, FAILED, NOT_DEPLOYED.
    type: str
  appTelemetryReadinessStatus:
    description:
      - >
        AppTelemetryReadinessStatus query parameter. Indicates whether the network device is ready for
        application telemetry enablement or not. Available values ENABLED, READY, NOT_READY, NOT_SUPPORTED.
    type: str
  cbarDeploymentStatus:
    description:
      - >
        CbarDeploymentStatus query parameter. Status of the CBAR deployment on the network device. Available
        values SCHEDULED, IN_PROGRESS, COMPLETED, FAILED, NOT_DEPLOYED.
    type: str
  cbarReadinessStatus:
    description:
      - >
        CbarReadinessStatus query parameter. Indicates whether the network device is ready for CBAR enablement
        or not. Available values ENABLED, READY, NOT_READY, NOT_SUPPORTED.
    type: str
  protocolPackStatus:
    description:
      - >
        ProtocolPackStatus query parameter. Indicates whether the NBAR protocol pack is up-to-date or not on the
        network device. Available values LATEST, OUTDATED, UNKNOWN.
    type: str
  protocolPackUpdateStatus:
    description:
      - >
        ProtocolPackUpdateStatus query parameter. Status of the NBAR protocol pack update on the network device.
        Available values SCHEDULED, IN_PROGRESS, SUCCESS, FAILED, NONE.
    type: str
  applicationRegistrySyncStatus:
    description:
      - >
        ApplicationRegistrySyncStatus query parameter. Indicates whether the latest definitions from application
        registry have been synchronized with the network device or not. Available values SYNCING, IN_SYNC,
        OUT_OF_SYNC, NOT_APPLICABLE.
    type: str
  offset:
    description:
      - >
        Offset query parameter. The first record to show for this page; the first record is numbered 1. Default
        value is 1.
    type: int
  limit:
    description:
      - Limit query parameter. The number of records to show for this page. Minimum value is 1, Maximum value is 500.
    type: int
  sortBy:
    description:
      - SortBy query parameter. A property within the response to sort by.
    type: str
  order:
    description:
      - >
        Order query parameter. Whether ascending or descending order should be used to sort the response.
        Available values are asc, desc. Default value is asc.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Application Policy RetrieveTheListOfNetworkDevicesWithTheirApplicationVisibilityStatus
    description: Complete reference of the RetrieveTheListOfNetworkDevicesWithTheirApplicationVisibilityStatus API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieve-the-list-of-network-devices-with-their-application-visibility-status
notes:
  - SDK Method used are
    application_policy.ApplicationPolicy.retrieve_the_list_of_network_devices_with_their_application_visibility_status,
  - Paths used are
    get /dna/intent/api/v1/applicationVisibility/networkDevices,
"""

EXAMPLES = r"""
---
- name: Get all Application Visibility Network Devices
  cisco.dnac.application_visibility_network_devices_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    ids: string
    managementAddress: string
    hostname: string
    siteId: string
    appTelemetryDeploymentStatus: string
    appTelemetryReadinessStatus: string
    cbarDeploymentStatus: string
    cbarReadinessStatus: string
    protocolPackStatus: string
    protocolPackUpdateStatus: string
    applicationRegistrySyncStatus: string
    offset: 0
    limit: 0
    sortBy: string
    order: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "managementAddress": "string",
          "hostname": "string",
          "siteId": "string",
          "appTelemetryDeploymentStatus": "string",
          "appTelemetryReadinessStatus": "string",
          "cbarDeploymentStatus": "string",
          "cbarReadinessStatus": "string",
          "protocolPackStatus": "string",
          "protocolPackUpdateStatus": "string",
          "applicationRegistrySyncStatus": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: license_last_operation_status_info
short_description: Information module for License Last Operation Status
description:
  - Get all License Last Operation Status. - > Retrieves the status of the last system licensing operation. If the operation
    does not exist or has not been triggered, the API responds with an HTTP 404 Not Found error.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Licenses SystemLicensingLastOperationStatus
    description: Complete reference of the SystemLicensingLastOperationStatus API.
    link: https://developer.cisco.com/docs/dna-center/#!system-licensing-last-operation-status
notes:
  - SDK Method used are
    licenses.Licenses.system_licensing_last_operation_status,
  - Paths used are
    get /dna/system/api/v1/license/lastOperationStatus,
"""

EXAMPLES = r"""
---
- name: Get all License Last Operation Status
  cisco.dnac.license_last_operation_status_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "status": "string",
        "isError": true,
        "failureReason": "string",
        "errorCode": "string",
        "lastUpdate": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: areas
short_description: Resource module for Areas
description:
  - Manage operations create, update and delete of the resource Areas.
  - Creates an area in the network hierarchy. - > Deletes an area in the network hierarchy. This operations fails if there
    are any child areas or buildings for this area.
  - Updates an area in the network hierarchy.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. Area ID.
    type: str
  name:
    description: Area name.
    type: str
  parentId:
    description: Parent Id.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Site Design CreatesAnArea
    description: Complete reference of the CreatesAnArea API.
    link: https://developer.cisco.com/docs/dna-center/#!creates-an-area
  - name: Cisco DNA Center documentation for Site Design DeletesAnArea
    description: Complete reference of the DeletesAnArea API.
    link: https://developer.cisco.com/docs/dna-center/#!deletes-an-area
  - name: Cisco DNA Center documentation for Site Design UpdatesAnArea
    description: Complete reference of the UpdatesAnArea API.
    link: https://developer.cisco.com/docs/dna-center/#!updates-an-area
notes:
  - SDK Method used are
    site_design.SiteDesign.creates_an_area,
    site_design.SiteDesign.deletes_an_area,
    site_design.SiteDesign.updates_an_area,
  - Paths used are
    post /dna/intent/api/v1/areas,
    delete /dna/intent/api/v1/areas/{id},
    put /dna/intent/api/v1/areas/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.areas:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    name: string
    parentId: string
- name: Delete by id
  cisco.dnac.areas:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Update by id
  cisco.dnac.areas:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    id: string
    name: string
    parentId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "count": 0
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sda_anycast_gateways_count_info
short_description: Information module for Sda Anycast Gateways Count
description:
  - Get all Sda Anycast Gateways Count.
  - Returns the count of anycast gateways that match the provided query parameters.
version_added: '6.14.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  fabricId:
    description:
      - FabricId query parameter. ID of the fabric the anycast gateway is assigned to.
    type: str
  virtualNetworkName:
    description:
      - VirtualNetworkName query parameter. Name of the virtual network associated with the anycast gateways.
    type: str
  ipPoolName:
    description:
      - IpPoolName query parameter. Name of the IP pool associated with the anycast gateways.
    type: str
  vlanName:
    description:
      - VlanName query parameter. VLAN name of the anycast gateways.
    type: str
  vlanId:
    description:
      - >
        VlanId query parameter. VLAN ID of the anycast gateways. The allowed range for vlanId is 2-4093 except
        for reserved VLANs 1002-1005, 2046, and 4094.
    type: float
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for SDA GetAnycastGatewayCount
    description: Complete reference of the GetAnycastGatewayCount API.
    link: https://developer.cisco.com/docs/dna-center/#!get-anycast-gateway-count
notes:
  - SDK Method used are
    sda.Sda.get_anycast_gateway_count,
  - Paths used are
    get /dna/intent/api/v1/sda/anycastGateways/count,
"""

EXAMPLES = r"""
---
- name: Get all Sda Anycast Gateways Count
  cisco.dnac.sda_anycast_gateways_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    fabricId: string
    virtualNetworkName: string
    ipPoolName: string
    vlanName: string
    vlanId: 0
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: filter_groups
short_description: Resource module for Filter Groups
description:
  - Manage operations create, update and delete of the resource Filter Groups.
  - Creates filter group with given filters.
  - For detailed information about the usage of the API, please refer to the Open API specification document
    https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/
    CE_Cat_Center_Org-FilterGroups-1.0.0-resolved.yaml.
  - Deletes the given filter group.
  - For detailed information about the usage of the API, please refer to the Open API specification document
    https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/
    CE_Cat_Center_Org-FilterGroups-1.0.0-resolved.yaml.
  - Updates the filter group for given id. The request payload should contain complete definition of the Filter Group.
  - For detailed information about the usage of the API, please refer to the Open API specification document
    https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/
    CE_Cat_Center_Org-FilterGroups-1.0.0-resolved.yaml.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  filters:
    description: Filter Groups's filters.
    elements: dict
    suboptions:
      key:
        description: Key.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: str
    type: list
  headers:
    description: Additional headers.
    type: dict
  id:
    description: Id path parameter. The id of the filter group to be deleted.
    type: str
  name:
    description: Name.
    type: str
  type:
    description: Type.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices CreateFilterGroup
    description: Complete reference of the CreateFilterGroup API.
    link: https://developer.cisco.com/docs/dna-center/#!create-filter-group
  - name: Cisco DNA Center documentation for Devices DeleteAFilterGroup
    description: Complete reference of the DeleteAFilterGroup API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-a-filter-group
  - name: Cisco DNA Center documentation for Devices UpdateFilterGroup
    description: Complete reference of the UpdateFilterGroup API.
    link: https://developer.cisco.com/docs/dna-center/#!update-filter-group
notes:
  - SDK Method used are
    devices.Devices.create_filter_group,
    devices.Devices.delete_a_filter_group,
    devices.Devices.update_filter_group,
  - Paths used are
    post /dna/intent/api/v1/filterGroups,
    delete /dna/intent/api/v1/filterGroups/{id},
    put /dna/intent/api/v1/filterGroups/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.filter_groups:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    filters:
      - key: string
        operator: string
        value: string
    headers: '{{my_headers | from_json}}'
    name: string
    type: string
- name: Delete by id
  cisco.dnac.filter_groups:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    headers: '{{my_headers | from_json}}'
    id: string
- name: Update by id
  cisco.dnac.filter_groups:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    filters:
      - key: string
        operator: string
        value: string
    headers: '{{my_headers | from_json}}'
    id: string
    name: string
    type: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "id": "string"
    }
"""
